@@ -1,16 +1,25 @@
 from .pyflint import *
+
 from .types.fmpz import *
 from .types.fmpz_poly import *
 from .types.fmpz_mat import *
 from .types.fmpz_series import *
+
 from .types.fmpq import *
 from .types.fmpq_poly import *
 from .types.fmpq_mat import *
 from .types.fmpq_series import *
+
 from .types.nmod import *
 from .types.nmod_poly import *
 from .types.nmod_mat import *
 from .types.nmod_series import *
+
+from .types.fmpz_mpoly import *
+from .types.fmpz_mod import *
+from .types.fmpz_mod_poly import *
+from .types.fmpz_mod_mat import fmpz_mod_mat
+
 from .types.arf import *
 from .types.arb import *
 from .types.arb_poly import *
@@ -20,6 +29,8 @@ from .types.acb import *
 from .types.acb_poly import *
 from .types.acb_mat import *
 from .types.acb_series import *
-from .types.fmpz_mpoly import *
 
-__version__ = '0.4.4'
+from .types.dirichlet import *
+from .functions.showgood import good, showgood
+
+__version__ = '0.6.0'
