@@ -52,10 +52,15 @@ def run_doctests(verbose=None):
     """Run the python-flint doctests"""
     # Here verbose=True shows a lot of output.
     modules = [flint.pyflint,
+               flint.flint_base.flint_base,
+               flint.flint_base.flint_context,
                flint.types.fmpz,
                flint.types.fmpz_poly,
                flint.types.fmpz_mat,
                flint.types.fmpz_series,
+               flint.types.fmpz_mod,
+               flint.types.fmpz_mod_poly,
+               flint.types.fmpz_mod_mat,
                flint.types.fmpq,
                flint.types.fmpq_poly,
                flint.types.fmpq_mat,
@@ -73,7 +78,8 @@ def run_doctests(verbose=None):
                flint.types.acb_poly,
                flint.types.acb_mat,
                flint.types.acb_series,
-               flint.types.dirichlet]
+               flint.types.dirichlet,
+               flint.functions.showgood]
     results = [doctest.testmod(x) for x in modules]
 #    ffmpz, tfmpz = doctest.testmod(flint._fmpz, verbose=verbose)
  #   failed, total = doctest.testmod(flint.pyflint, verbose=verbose)
